/*
 * Copyright 2006 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * $Id: SequenceGenerator.java 420313 2006-07-09 16:42:46Z gvanmatre $
 */
package org.apache.shale.clay.component.chain;

/**
 * <p>Generates a unique id used to identify each component in the component tree.
 * The id's will be prefixed with "_idsc" followed by a sequential incremented
 * number.  This class will be used outside of the implementation of the
 * <code>UIViewRoot</code>'s createUniqueId method.  This object will be cached
 * in request scope each time the view is rendered and the component tree contains
 * one or more {@link org.apache.shale.clay.component.Clay} components.<br/><br/>
 * This class is only used with the myfaces implementation.</p>
 */
public class SequenceGenerator {
   /**
    * <p>Holds the id prefix of "_idsc".  The <code>uniqueId</code>
    * is appended for each call to <code>createUniqueId</code>.</p>
    */
   private StringBuffer buff = new StringBuffer("_idsc");

   /**
    * <p>Sequencial generated unique number for the object instance.</p>
    */
   private int uniqueId = 0;

   /**
    * <p>Returns a unique component id prefixed with "_idsc".</p>
    *
    * @return a unique id per object instance
    */
   public String createUniqueId() {
       buff.setLength("_idsc".length());
       buff.append(uniqueId++);
       return buff.toString();
   }
}
