/*
 * Copyright 2005 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/*
 * $Id: PluggableLookupCommand.java 420313 2006-07-09 16:42:46Z gvanmatre $
 */
package org.apache.shale.clay.utils;

import org.apache.commons.chain.CatalogFactory;
import org.apache.commons.chain.Context;
import org.apache.commons.chain.generic.LookupCommand;

/**
 * <p>This chains class performs a check to verify the catalog exists.
 * If the catalog doesn't exist, it returns <code>true</code> if the
 * <code>optional</code> property in the super class is <code>true</code>.
 * If the catalog is not found and the command is not optional, it returns a
 * <code>false</code> value.  Otherwise, if the catalog exists, the super
 * implementation is invoked.</p>
 *
 */
public class PluggableLookupCommand extends LookupCommand {


    /**
     * <p>Checks to see if the catalog exists.</p>
     *
     * @return <code>true</code> if the catalog exists
     */
    private boolean catalogExists() {
        String catalogName = getCatalogName();
        if (catalogName == null) {
            return false;
        }
        CatalogFactory catalogFactory = CatalogFactory.getInstance();

        return (catalogFactory.getCatalog(catalogName) != null);
    }

    /**
     * <p>Adds an additional check to determine if the catalog name is loaded.
     * If loaded, the super implementation is invoked.  Otherwise, the chain
     * continues if the command is optional.</p>
     *
     * @param context chains context
     * @return <code>true</code> if the chain is done
     * @exception Exception up the calling chain
     */
    public boolean execute(Context context) throws Exception {

        if (!catalogExists()) {
           return !isOptional();
        }

        return super.execute(context);
    }

}
